@@ -2,7 +2,6 @@ import struct
 
 from dissect import cstruct
 
-
 ntfs_def = """
 /* ================ Generic stuff ================ */
 
@@ -192,6 +191,89 @@ typedef struct _FILE_NAME {
     WCHAR       FileName[FileNameLength];
 } FILE_NAME;
 
+enum IO_REPARSE_TAG : ULONG {
+    RESERVED_ZERO           = 0x00000000,
+    RESERVED_ONE            = 0x00000001,
+    RESERVED_TWO            = 0x00000002,
+    MOUNT_POINT             = 0xA0000003,
+    HSM                     = 0xC0000004,
+    DRIVE_EXTENDER          = 0x80000005,
+    HSM2                    = 0x80000006,
+    SIS                     = 0x80000007,
+    WIM                     = 0x80000008,
+    CSV                     = 0x80000009,
+    DFS                     = 0x8000000A,
+    FILTER_MANAGER          = 0x8000000B,
+    SYMLINK                 = 0xA000000C,
+    IIS_CACHE               = 0xA0000010,
+    DFSR                    = 0x80000012,
+    DEDUP                   = 0x80000013,
+    APPXSTRM                = 0xC0000014,
+    NFS                     = 0x80000014,
+    FILE_PLACEHOLDER        = 0x80000015,
+    DFM                     = 0x80000016,
+    WOF                     = 0x80000017,
+    WCI                     = 0x80000018,
+    WCI_1                   = 0x90001018,
+    GLOBAL_REPARSE          = 0xA0000019,
+    CLOUD                   = 0x9000001A,
+    CLOUD_1                 = 0x9000101A,
+    CLOUD_2                 = 0x9000201A,
+    CLOUD_3                 = 0x9000301A,
+    CLOUD_4                 = 0x9000401A,
+    CLOUD_5                 = 0x9000501A,
+    CLOUD_6                 = 0x9000601A,
+    CLOUD_7                 = 0x9000701A,
+    CLOUD_8                 = 0x9000801A,
+    CLOUD_9                 = 0x9000901A,
+    CLOUD_A                 = 0x9000A01A,
+    CLOUD_B                 = 0x9000B01A,
+    CLOUD_C                 = 0x9000C01A,
+    CLOUD_D                 = 0x9000D01A,
+    CLOUD_E                 = 0x9000E01A,
+    CLOUD_F                 = 0x9000F01A,
+    APPEXECLINK             = 0x8000001B,
+    PROJFS                  = 0x9000001C,
+    LX_SYMLINK              = 0xA000001D,
+    STORAGE_SYNC            = 0x8000001E,
+    WCI_TOMBSTONE           = 0xA000001F,
+    UNHANDLED               = 0x80000020,
+    ONEDRIVE                = 0x80000021,
+    PROJFS_TOMBSTONE        = 0xA0000022,
+    AF_UNIX                 = 0x80000023,
+    LX_FIFO                 = 0x80000024,
+    LX_CHR                  = 0x80000025,
+    LX_BLK                  = 0x80000026,
+    WCI_LINK                = 0xA0000027,
+    WCI_LINK_1              = 0xA0001027,
+};
+
+typedef struct _REPARSE_DATA_BUFFER {
+    IO_REPARSE_TAG  ReparseTag;
+    USHORT      ReparseDataLength;
+    USHORT      Reserved;
+} REPARSE_DATA_BUFFER;
+
+enum SYMLINK_FLAG : ULONG {
+    ABSOLUTE                = 0x00000000,
+    RELATIVE                = 0x00000001,
+};
+
+typedef struct _SYMBOLIC_LINK_REPARSE_BUFFER {
+    USHORT  SubstituteNameOffset;
+    USHORT  SubstituteNameLength;
+    USHORT  PrintNameOffset;
+    USHORT  PrintNameLength;
+    SYMLINK_FLAG    Flags;
+} SYMBOLIC_LINK_REPARSE_BUFFER;
+
+typedef struct _MOUNT_POINT_REPARSE_BUFFER {
+    USHORT  SubstituteNameOffset;
+    USHORT  SubstituteNameLength;
+    USHORT  PrintNameOffset;
+    USHORT  PrintNameLength;
+} _MOUNT_POINT_REPARSE_BUFFER;
+
 /* ================ Index ================ */
 
 enum COLLATION : ULONG {
@@ -398,7 +480,7 @@ flag USN_SOURCE : DWORD {
 };
 
 typedef struct _FILE_ID_128 {
-    BYTE    Identifier[16];
+    BYTE        Identifier[16];
 } FILE_ID_128;
 
 typedef struct {
@@ -464,6 +546,7 @@ c_ntfs.load(ntfs_def)
 
 # Useful enums and flags
 ATTRIBUTE_TYPE_CODE = c_ntfs.ATTRIBUTE_TYPE_CODE
+IO_REPARSE_TAG = c_ntfs.IO_REPARSE_TAG
 ACCESS_MASK = c_ntfs.ACCESS_MASK
 ACE_TYPE = c_ntfs.ACE_TYPE
 COLLATION = c_ntfs.COLLATION
